<?php

namespace App\Livewire;

use Livewire\Component;
use App\Models\Sucursal;
use App\Models\Producto;
use App\Models\DetalleTraspaso;
use Illuminate\Support\Facades\Auth;
use Livewire\Attributes\Validate;

class InformeVentaProducto extends Component
{
    #[Validate('required', message: 'La Sucursal es requerida.')]
    #[Validate('integer', message: 'La Sucursal debe ser entera.')]
    public $sucursal_id;
    #[Validate('required', message: 'La Fecha es requerida.')]
    public $fecha;
    public $sucursal;

    public $resultados = [];

    public function render()
    {
        $sucursales     = Sucursal::whereNull('deleted_at')->get();

        return view('livewire.venta-producto',compact(
            'sucursales'
        ));
    }

    public function buscar()
    {
        $this->validate([
            'sucursal_id' => 'required|integer',
            'fecha'       => 'required'
        ]);

        $productos = Producto::whereNull('deleted_at')->orderBy('nombre', 'ASC')->get();
        $this->resultados = [];
        //$total = 0;
        foreach ($productos as $key => $item) {
            $producto           = Producto::find($item->id);
            $nombre             = $producto->nombre;
            $stock              = $producto->stock($item->id);
            $cantidad           = DetalleTraspaso::cantidad($producto->id, $this->sucursal_id, $this->fecha)[0]->cantidad ?? 0;
            $saldo              = Sucursal::stockAyer($producto->id, $this->sucursal_id, $this->fecha)[0]->saldo ?? 0;
            $stockSucursal      = $cantidad+$saldo;
            $total              = $stock+$stockSucursal;
            $valorizacion       = $producto->precio_compra*$total;
            
            array_push($this->resultados, [
                'producto'          => $producto,
                'nombre'            => $nombre,
                'stock'             => $stock,
                'stockSucursal'     => $stockSucursal,
                'total'             => $total,
                'valorizacion'      => $valorizacion
            ]);
            $this->sucursal = Sucursal::find($this->sucursal_id);

            if (count($this->resultados)>0) {
                $this->dispatch('alerta', [
                    'title'             => 'Inventario valorado cargado exitosamente.',
                    'timer'             => 3000,
                    'icon'              => 'success',
                    'toast'             => true,
                    'showConfirmButton' => false,
                    'position'          => 'top-right'
                ]) ;
            }
        }
    }

}
